@@ -52,7 +52,7 @@ fn main() -> io::Result<()> {
 			if !opt.dry_run {
 				repository.command(&["add", "--all"])?;
 
-				let base_options = vec!["commit", "--allow-empty-message", "--no-edit"];
+				let base_options = vec!["commit", "--allow-empty-message"];
 
 				let message_options = if opt.message.is_empty() && repository.head_is_failing_ref()
 				{
@@ -61,6 +61,22 @@ fn main() -> io::Result<()> {
 					vec!["--message", &opt.message]
 				};
 
+				let edit_options = if opt.edit {
+					vec!["--edit"]
+				} else {
+					vec!["--no-edit"]
+				};
+
+				let fixup_options = match &opt.fixup {
+					Some(commit) => vec!["--fixup", commit],
+					None => vec![],
+				};
+
+				let squash_options = match &opt.squash {
+					Some(commit) => vec!["--squash", commit],
+					None => vec![],
+				};
+
 				let amend_options = if repository.head_is_failing_ref() {
 					vec!["--amend"]
 				} else {
@@ -77,6 +93,9 @@ fn main() -> io::Result<()> {
 					&[
 						base_options,
 						message_options,
+						edit_options,
+						fixup_options,
+						squash_options,
 						amend_options,
 						no_verify_options,
 					]
